import reflex as rx

class VscAccount(rx.Component):
    library = "react-icons/vsc"
    tag = "VscAccount"


class VscActivateBreakpoints(rx.Component):
    library = "react-icons/vsc"
    tag = "VscActivateBreakpoints"


class VscAdd(rx.Component):
    library = "react-icons/vsc"
    tag = "VscAdd"


class VscArchive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArchive"


class VscArrowBoth(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowBoth"


class VscArrowCircleDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowCircleDown"


class VscArrowCircleLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowCircleLeft"


class VscArrowCircleRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowCircleRight"


class VscArrowCircleUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowCircleUp"


class VscArrowDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowDown"


class VscArrowLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowLeft"


class VscArrowRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowRight"


class VscArrowSmallDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowSmallDown"


class VscArrowSmallLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowSmallLeft"


class VscArrowSmallRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowSmallRight"


class VscArrowSmallUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowSmallUp"


class VscArrowSwap(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowSwap"


class VscArrowUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscArrowUp"


class VscAzureDevops(rx.Component):
    library = "react-icons/vsc"
    tag = "VscAzureDevops"


class VscAzure(rx.Component):
    library = "react-icons/vsc"
    tag = "VscAzure"


class VscBeakerStop(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBeakerStop"


class VscBeaker(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBeaker"


class VscBellDot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBellDot"


class VscBellSlashDot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBellSlashDot"


class VscBellSlash(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBellSlash"


class VscBell(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBell"


class VscBlank(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBlank"


class VscBold(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBold"


class VscBook(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBook"


class VscBookmark(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBookmark"


class VscBracketDot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBracketDot"


class VscBracketError(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBracketError"


class VscBriefcase(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBriefcase"


class VscBroadcast(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBroadcast"


class VscBrowser(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBrowser"


class VscBug(rx.Component):
    library = "react-icons/vsc"
    tag = "VscBug"


class VscCalendar(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCalendar"


class VscCallIncoming(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCallIncoming"


class VscCallOutgoing(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCallOutgoing"


class VscCaseSensitive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCaseSensitive"


class VscCheckAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCheckAll"


class VscCheck(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCheck"


class VscChecklist(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChecklist"


class VscChevronDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChevronDown"


class VscChevronLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChevronLeft"


class VscChevronRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChevronRight"


class VscChevronUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChevronUp"


class VscChromeClose(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChromeClose"


class VscChromeMaximize(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChromeMaximize"


class VscChromeMinimize(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChromeMinimize"


class VscChromeRestore(rx.Component):
    library = "react-icons/vsc"
    tag = "VscChromeRestore"


class VscCircleFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleFilled"


class VscCircleLargeFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleLargeFilled"


class VscCircleLarge(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleLarge"


class VscCircleSlash(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleSlash"


class VscCircleSmallFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleSmallFilled"


class VscCircleSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircleSmall"


class VscCircle(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircle"


class VscCircuitBoard(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCircuitBoard"


class VscClearAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscClearAll"


class VscClippy(rx.Component):
    library = "react-icons/vsc"
    tag = "VscClippy"


class VscCloseAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCloseAll"


class VscClose(rx.Component):
    library = "react-icons/vsc"
    tag = "VscClose"


class VscCloudDownload(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCloudDownload"


class VscCloudUpload(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCloudUpload"


class VscCloud(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCloud"


class VscCode(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCode"


class VscCollapseAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCollapseAll"


class VscColorMode(rx.Component):
    library = "react-icons/vsc"
    tag = "VscColorMode"


class VscCombine(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCombine"


class VscCommentDiscussion(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCommentDiscussion"


class VscCommentDraft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCommentDraft"


class VscCommentUnresolved(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCommentUnresolved"


class VscComment(rx.Component):
    library = "react-icons/vsc"
    tag = "VscComment"


class VscCompassActive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCompassActive"


class VscCompassDot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCompassDot"


class VscCompass(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCompass"


class VscCopy(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCopy"


class VscCreditCard(rx.Component):
    library = "react-icons/vsc"
    tag = "VscCreditCard"


class VscDash(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDash"


class VscDashboard(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDashboard"


class VscDatabase(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDatabase"


class VscDebugAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugAll"


class VscDebugAltSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugAltSmall"


class VscDebugAlt(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugAlt"


class VscDebugBreakpointConditionalUnverified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointConditionalUnverified"


class VscDebugBreakpointConditional(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointConditional"


class VscDebugBreakpointDataUnverified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointDataUnverified"


class VscDebugBreakpointData(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointData"


class VscDebugBreakpointFunctionUnverified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointFunctionUnverified"


class VscDebugBreakpointFunction(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointFunction"


class VscDebugBreakpointLogUnverified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointLogUnverified"


class VscDebugBreakpointLog(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointLog"


class VscDebugBreakpointUnsupported(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugBreakpointUnsupported"


class VscDebugConsole(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugConsole"


class VscDebugContinueSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugContinueSmall"


class VscDebugContinue(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugContinue"


class VscDebugCoverage(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugCoverage"


class VscDebugDisconnect(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugDisconnect"


class VscDebugLineByLine(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugLineByLine"


class VscDebugPause(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugPause"


class VscDebugRerun(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugRerun"


class VscDebugRestartFrame(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugRestartFrame"


class VscDebugRestart(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugRestart"


class VscDebugReverseContinue(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugReverseContinue"


class VscDebugStackframeActive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStackframeActive"


class VscDebugStackframe(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStackframe"


class VscDebugStart(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStart"


class VscDebugStepBack(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStepBack"


class VscDebugStepInto(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStepInto"


class VscDebugStepOut(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStepOut"


class VscDebugStepOver(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStepOver"


class VscDebugStop(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebugStop"


class VscDebug(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDebug"


class VscDesktopDownload(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDesktopDownload"


class VscDeviceCameraVideo(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDeviceCameraVideo"


class VscDeviceCamera(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDeviceCamera"


class VscDeviceMobile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDeviceMobile"


class VscDiffAdded(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiffAdded"


class VscDiffIgnored(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiffIgnored"


class VscDiffModified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiffModified"


class VscDiffRemoved(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiffRemoved"


class VscDiffRenamed(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiffRenamed"


class VscDiff(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiff"


class VscDiscard(rx.Component):
    library = "react-icons/vsc"
    tag = "VscDiscard"


class VscEdit(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEdit"


class VscEditorLayout(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEditorLayout"


class VscEllipsis(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEllipsis"


class VscEmptyWindow(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEmptyWindow"


class VscErrorSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscErrorSmall"


class VscError(rx.Component):
    library = "react-icons/vsc"
    tag = "VscError"


class VscExclude(rx.Component):
    library = "react-icons/vsc"
    tag = "VscExclude"


class VscExpandAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscExpandAll"


class VscExport(rx.Component):
    library = "react-icons/vsc"
    tag = "VscExport"


class VscExtensions(rx.Component):
    library = "react-icons/vsc"
    tag = "VscExtensions"


class VscEyeClosed(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEyeClosed"


class VscEye(rx.Component):
    library = "react-icons/vsc"
    tag = "VscEye"


class VscFeedback(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFeedback"


class VscFileBinary(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileBinary"


class VscFileCode(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileCode"


class VscFileMedia(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileMedia"


class VscFilePdf(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFilePdf"


class VscFileSubmodule(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileSubmodule"


class VscFileSymlinkDirectory(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileSymlinkDirectory"


class VscFileSymlinkFile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileSymlinkFile"


class VscFileZip(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFileZip"


class VscFile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFile"


class VscFiles(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFiles"


class VscFilterFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFilterFilled"


class VscFilter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFilter"


class VscFlame(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFlame"


class VscFoldDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFoldDown"


class VscFoldUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFoldUp"


class VscFold(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFold"


class VscFolderActive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFolderActive"


class VscFolderLibrary(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFolderLibrary"


class VscFolderOpened(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFolderOpened"


class VscFolder(rx.Component):
    library = "react-icons/vsc"
    tag = "VscFolder"


class VscGear(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGear"


class VscGift(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGift"


class VscGistSecret(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGistSecret"


class VscGist(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGist"


class VscGitCommit(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitCommit"


class VscGitCompare(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitCompare"


class VscGitMerge(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitMerge"


class VscGitPullRequestClosed(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequestClosed"


class VscGitPullRequestCreate(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequestCreate"


class VscGitPullRequestDraft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequestDraft"


class VscGitPullRequestGoToChanges(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequestGoToChanges"


class VscGitPullRequestNewChanges(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequestNewChanges"


class VscGitPullRequest(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGitPullRequest"


class VscGithubAction(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGithubAction"


class VscGithubAlt(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGithubAlt"


class VscGithubInverted(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGithubInverted"


class VscGithub(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGithub"


class VscGlobe(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGlobe"


class VscGoToFile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGoToFile"


class VscGrabber(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGrabber"


class VscGraphLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGraphLeft"


class VscGraphLine(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGraphLine"


class VscGraphScatter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGraphScatter"


class VscGraph(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGraph"


class VscGripper(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGripper"


class VscGroupByRefType(rx.Component):
    library = "react-icons/vsc"
    tag = "VscGroupByRefType"


class VscHeartFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHeartFilled"


class VscHeart(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHeart"


class VscHistory(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHistory"


class VscHome(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHome"


class VscHorizontalRule(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHorizontalRule"


class VscHubot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscHubot"


class VscInbox(rx.Component):
    library = "react-icons/vsc"
    tag = "VscInbox"


class VscIndent(rx.Component):
    library = "react-icons/vsc"
    tag = "VscIndent"


class VscInfo(rx.Component):
    library = "react-icons/vsc"
    tag = "VscInfo"


class VscInsert(rx.Component):
    library = "react-icons/vsc"
    tag = "VscInsert"


class VscInspect(rx.Component):
    library = "react-icons/vsc"
    tag = "VscInspect"


class VscIssueDraft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscIssueDraft"


class VscIssueReopened(rx.Component):
    library = "react-icons/vsc"
    tag = "VscIssueReopened"


class VscIssues(rx.Component):
    library = "react-icons/vsc"
    tag = "VscIssues"


class VscItalic(rx.Component):
    library = "react-icons/vsc"
    tag = "VscItalic"


class VscJersey(rx.Component):
    library = "react-icons/vsc"
    tag = "VscJersey"


class VscJson(rx.Component):
    library = "react-icons/vsc"
    tag = "VscJson"


class VscKebabVertical(rx.Component):
    library = "react-icons/vsc"
    tag = "VscKebabVertical"


class VscKey(rx.Component):
    library = "react-icons/vsc"
    tag = "VscKey"


class VscLaw(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLaw"


class VscLayersActive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayersActive"


class VscLayersDot(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayersDot"


class VscLayers(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayers"


class VscLayoutActivitybarLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutActivitybarLeft"


class VscLayoutActivitybarRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutActivitybarRight"


class VscLayoutCentered(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutCentered"


class VscLayoutMenubar(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutMenubar"


class VscLayoutPanelCenter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanelCenter"


class VscLayoutPanelJustify(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanelJustify"


class VscLayoutPanelLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanelLeft"


class VscLayoutPanelOff(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanelOff"


class VscLayoutPanelRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanelRight"


class VscLayoutPanel(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutPanel"


class VscLayoutSidebarLeftOff(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutSidebarLeftOff"


class VscLayoutSidebarLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutSidebarLeft"


class VscLayoutSidebarRightOff(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutSidebarRightOff"


class VscLayoutSidebarRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutSidebarRight"


class VscLayoutStatusbar(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayoutStatusbar"


class VscLayout(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLayout"


class VscLibrary(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLibrary"


class VscLightbulbAutofix(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLightbulbAutofix"


class VscLightbulb(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLightbulb"


class VscLinkExternal(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLinkExternal"


class VscLink(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLink"


class VscListFilter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListFilter"


class VscListFlat(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListFlat"


class VscListOrdered(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListOrdered"


class VscListSelection(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListSelection"


class VscListTree(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListTree"


class VscListUnordered(rx.Component):
    library = "react-icons/vsc"
    tag = "VscListUnordered"


class VscLiveShare(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLiveShare"


class VscLoading(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLoading"


class VscLocation(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLocation"


class VscLockSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLockSmall"


class VscLock(rx.Component):
    library = "react-icons/vsc"
    tag = "VscLock"


class VscMagnet(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMagnet"


class VscMailRead(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMailRead"


class VscMail(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMail"


class VscMapFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMapFilled"


class VscMap(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMap"


class VscMarkdown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMarkdown"


class VscMegaphone(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMegaphone"


class VscMention(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMention"


class VscMenu(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMenu"


class VscMerge(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMerge"


class VscMilestone(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMilestone"


class VscMirror(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMirror"


class VscMortarBoard(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMortarBoard"


class VscMove(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMove"


class VscMultipleWindows(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMultipleWindows"


class VscMute(rx.Component):
    library = "react-icons/vsc"
    tag = "VscMute"


class VscNewFile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNewFile"


class VscNewFolder(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNewFolder"


class VscNewline(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNewline"


class VscNoNewline(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNoNewline"


class VscNote(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNote"


class VscNotebookTemplate(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNotebookTemplate"


class VscNotebook(rx.Component):
    library = "react-icons/vsc"
    tag = "VscNotebook"


class VscOctoface(rx.Component):
    library = "react-icons/vsc"
    tag = "VscOctoface"


class VscOpenPreview(rx.Component):
    library = "react-icons/vsc"
    tag = "VscOpenPreview"


class VscOrganization(rx.Component):
    library = "react-icons/vsc"
    tag = "VscOrganization"


class VscOutput(rx.Component):
    library = "react-icons/vsc"
    tag = "VscOutput"


class VscPackage(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPackage"


class VscPaintcan(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPaintcan"


class VscPassFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPassFilled"


class VscPass(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPass"


class VscPersonAdd(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPersonAdd"


class VscPerson(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPerson"


class VscPieChart(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPieChart"


class VscPin(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPin"


class VscPinnedDirty(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPinnedDirty"


class VscPinned(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPinned"


class VscPlayCircle(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPlayCircle"


class VscPlay(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPlay"


class VscPlug(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPlug"


class VscPreserveCase(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPreserveCase"


class VscPreview(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPreview"


class VscPrimitiveSquare(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPrimitiveSquare"


class VscProject(rx.Component):
    library = "react-icons/vsc"
    tag = "VscProject"


class VscPulse(rx.Component):
    library = "react-icons/vsc"
    tag = "VscPulse"


class VscQuestion(rx.Component):
    library = "react-icons/vsc"
    tag = "VscQuestion"


class VscQuote(rx.Component):
    library = "react-icons/vsc"
    tag = "VscQuote"


class VscRadioTower(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRadioTower"


class VscReactions(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReactions"


class VscRecordKeys(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRecordKeys"


class VscRecordSmall(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRecordSmall"


class VscRecord(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRecord"


class VscRedo(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRedo"


class VscReferences(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReferences"


class VscRefresh(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRefresh"


class VscRegex(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRegex"


class VscRemoteExplorer(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRemoteExplorer"


class VscRemote(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRemote"


class VscRemove(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRemove"


class VscReplaceAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReplaceAll"


class VscReplace(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReplace"


class VscReply(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReply"


class VscRepoClone(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepoClone"


class VscRepoForcePush(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepoForcePush"


class VscRepoForked(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepoForked"


class VscRepoPull(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepoPull"


class VscRepoPush(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepoPush"


class VscRepo(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRepo"


class VscReport(rx.Component):
    library = "react-icons/vsc"
    tag = "VscReport"


class VscRequestChanges(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRequestChanges"


class VscRocket(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRocket"


class VscRootFolderOpened(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRootFolderOpened"


class VscRootFolder(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRootFolder"


class VscRss(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRss"


class VscRuby(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRuby"


class VscRunAbove(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRunAbove"


class VscRunAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRunAll"


class VscRunBelow(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRunBelow"


class VscRunErrors(rx.Component):
    library = "react-icons/vsc"
    tag = "VscRunErrors"


class VscSaveAll(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSaveAll"


class VscSaveAs(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSaveAs"


class VscSave(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSave"


class VscScreenFull(rx.Component):
    library = "react-icons/vsc"
    tag = "VscScreenFull"


class VscScreenNormal(rx.Component):
    library = "react-icons/vsc"
    tag = "VscScreenNormal"


class VscSearchFuzzy(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSearchFuzzy"


class VscSearchStop(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSearchStop"


class VscSearch(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSearch"


class VscSend(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSend"


class VscServerEnvironment(rx.Component):
    library = "react-icons/vsc"
    tag = "VscServerEnvironment"


class VscServerProcess(rx.Component):
    library = "react-icons/vsc"
    tag = "VscServerProcess"


class VscServer(rx.Component):
    library = "react-icons/vsc"
    tag = "VscServer"


class VscSettingsGear(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSettingsGear"


class VscSettings(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSettings"


class VscShield(rx.Component):
    library = "react-icons/vsc"
    tag = "VscShield"


class VscSignIn(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSignIn"


class VscSignOut(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSignOut"


class VscSmiley(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSmiley"


class VscSortPrecedence(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSortPrecedence"


class VscSourceControl(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSourceControl"


class VscSparkle(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSparkle"


class VscSplitHorizontal(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSplitHorizontal"


class VscSplitVertical(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSplitVertical"


class VscSquirrel(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSquirrel"


class VscStarEmpty(rx.Component):
    library = "react-icons/vsc"
    tag = "VscStarEmpty"


class VscStarFull(rx.Component):
    library = "react-icons/vsc"
    tag = "VscStarFull"


class VscStarHalf(rx.Component):
    library = "react-icons/vsc"
    tag = "VscStarHalf"


class VscStopCircle(rx.Component):
    library = "react-icons/vsc"
    tag = "VscStopCircle"


class VscSymbolArray(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolArray"


class VscSymbolBoolean(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolBoolean"


class VscSymbolClass(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolClass"


class VscSymbolColor(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolColor"


class VscSymbolConstant(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolConstant"


class VscSymbolEnumMember(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolEnumMember"


class VscSymbolEnum(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolEnum"


class VscSymbolEvent(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolEvent"


class VscSymbolField(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolField"


class VscSymbolFile(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolFile"


class VscSymbolInterface(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolInterface"


class VscSymbolKey(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolKey"


class VscSymbolKeyword(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolKeyword"


class VscSymbolMethod(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolMethod"


class VscSymbolMisc(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolMisc"


class VscSymbolNamespace(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolNamespace"


class VscSymbolNumeric(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolNumeric"


class VscSymbolOperator(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolOperator"


class VscSymbolParameter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolParameter"


class VscSymbolProperty(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolProperty"


class VscSymbolRuler(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolRuler"


class VscSymbolSnippet(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolSnippet"


class VscSymbolString(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolString"


class VscSymbolStructure(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolStructure"


class VscSymbolVariable(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSymbolVariable"


class VscSyncIgnored(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSyncIgnored"


class VscSync(rx.Component):
    library = "react-icons/vsc"
    tag = "VscSync"


class VscTable(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTable"


class VscTag(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTag"


class VscTarget(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTarget"


class VscTasklist(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTasklist"


class VscTelescope(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTelescope"


class VscTerminalBash(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalBash"


class VscTerminalCmd(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalCmd"


class VscTerminalDebian(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalDebian"


class VscTerminalLinux(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalLinux"


class VscTerminalPowershell(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalPowershell"


class VscTerminalTmux(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalTmux"


class VscTerminalUbuntu(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminalUbuntu"


class VscTerminal(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTerminal"


class VscTextSize(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTextSize"


class VscThreeBars(rx.Component):
    library = "react-icons/vsc"
    tag = "VscThreeBars"


class VscThumbsdown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscThumbsdown"


class VscThumbsup(rx.Component):
    library = "react-icons/vsc"
    tag = "VscThumbsup"


class VscTools(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTools"


class VscTrash(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTrash"


class VscTriangleDown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTriangleDown"


class VscTriangleLeft(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTriangleLeft"


class VscTriangleRight(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTriangleRight"


class VscTriangleUp(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTriangleUp"


class VscTwitter(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTwitter"


class VscTypeHierarchySub(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTypeHierarchySub"


class VscTypeHierarchySuper(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTypeHierarchySuper"


class VscTypeHierarchy(rx.Component):
    library = "react-icons/vsc"
    tag = "VscTypeHierarchy"


class VscUnfold(rx.Component):
    library = "react-icons/vsc"
    tag = "VscUnfold"


class VscUngroupByRefType(rx.Component):
    library = "react-icons/vsc"
    tag = "VscUngroupByRefType"


class VscUnlock(rx.Component):
    library = "react-icons/vsc"
    tag = "VscUnlock"


class VscUnmute(rx.Component):
    library = "react-icons/vsc"
    tag = "VscUnmute"


class VscUnverified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscUnverified"


class VscVariableGroup(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVariableGroup"


class VscVerifiedFilled(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVerifiedFilled"


class VscVerified(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVerified"


class VscVersions(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVersions"


class VscVmActive(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVmActive"


class VscVmConnect(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVmConnect"


class VscVmOutline(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVmOutline"


class VscVmRunning(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVmRunning"


class VscVm(rx.Component):
    library = "react-icons/vsc"
    tag = "VscVm"


class VscWand(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWand"


class VscWarning(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWarning"


class VscWatch(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWatch"


class VscWhitespace(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWhitespace"


class VscWholeWord(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWholeWord"


class VscWindow(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWindow"


class VscWordWrap(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWordWrap"


class VscWorkspaceTrusted(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWorkspaceTrusted"


class VscWorkspaceUnknown(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWorkspaceUnknown"


class VscWorkspaceUntrusted(rx.Component):
    library = "react-icons/vsc"
    tag = "VscWorkspaceUntrusted"


class VscZoomIn(rx.Component):
    library = "react-icons/vsc"
    tag = "VscZoomIn"


class VscZoomOut(rx.Component):
    library = "react-icons/vsc"
    tag = "VscZoomOut"


